django-unitology
================

Authored by `Basil Shubin <https://github.com/bashu>`_,  and some great
`contributors <https://github.com/bashu/django-unitology/contributors>`_.

.. image:: https://img.shields.io/pypi/v/django-unitology.svg
    :target: https://pypi.python.org/pypi/django-unitology/

.. image:: https://img.shields.io/pypi/dm/django-unitology.svg
    :target: https://pypi.python.org/pypi/django-unitology/

.. image:: https://img.shields.io/github/license/bashu/django-unitology.svg
    :target: https://pypi.python.org/pypi/django-unitology/

.. image:: https://img.shields.io/travis/bashu/django-unitology.svg
    :target: https://travis-ci.org/bashu/django-unitology/
